/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita.swing;

import java.awt.Component;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.HierarchyEvent;
import java.awt.event.HierarchyListener;

import javax.swing.DefaultCellEditor;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.SwingConstants;

import jp.ac.hosei.k.cis.java2005.dita.BinaryEditorUtil;

/**
 * エディット時に全てのテキストが選択されているエディタ。
 * @author arakawa
 * @version $Id: BinaryEditorCellEditor.java,v 1.1 2005/11/17 05:14:12 java2005 Exp $
 */
public class BinaryEditorCellEditor extends DefaultCellEditor {

    private static final long serialVersionUID = 1L;

    private final JTextField editor;

    /**
     * インスタンスを作成。
     */
    public BinaryEditorCellEditor() {
        super(new JTextField());
        final JTextField tf = (JTextField) this.editorComponent;
        this.editor = tf;
        this.editor.setHorizontalAlignment(SwingConstants.CENTER);
        this.editor.addFocusListener(new FocusAdapter() {
            public void focusLost(FocusEvent e) {
                stopCellEditing();
            }
        });
        this.editor.addHierarchyListener(new HierarchyListener() {
            public void hierarchyChanged(HierarchyEvent e) {
                if ((e.getChangeFlags() | HierarchyEvent.SHOWING_CHANGED) != 0) {
                    if (tf.isShowing()) {
                        tf.requestFocus();
                    }
                }
            }
        });
        
    }

    /**
     * 指定した位置のエディタを返す。
     * @param table 対象のテーブル
     * @param value 表示する値
     * @param isSelected 選択されているかどうかを表すフラグ
     * @param row 選択された行
     * @param column 選択された列
     * @return 返す値
     */
    public Component getTableCellEditorComponent(JTable table, Object value, boolean isSelected, int row, int column) {
        Object hook;
        if (value instanceof Integer) {
            Integer n = (Integer) value;
            hook = BinaryEditorUtil.toHexString(n.intValue());
        }
        else {
            hook = value;
        }
        Component ret = super.getTableCellEditorComponent(table, hook, isSelected, row, column);
        this.editor.select(0, (this.editor.getText()).length());
        this.editor.requestFocus();
        return ret;
    }
}
