/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita.swing;

import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

import jp.ac.hosei.k.cis.java2005.dita.BinaryEditorUtil;

/**
 * エディタの各セルをレンダリングするレンダラ。
 * @author arakawa
 * @version $Id: BinaryEditorCellRenderer.java,v 1.1 2005/11/17 05:14:12 java2005 Exp $
 */
public class BinaryEditorCellRenderer extends DefaultTableCellRenderer {

    private static final long serialVersionUID = 1L;

    /**
     * インスタンスを生成する。
     */
    public BinaryEditorCellRenderer() {
        super();
        this.setHorizontalAlignment(SwingConstants.CENTER);
    }

    /**
     * 値を設定する際に呼び出される。
     * @param value 設定する値
     */
    protected void setValue(Object value) {
        if (value == null) {
            super.setValue(BinaryEditorUtil.toHexString(-1));
        }
        else if (value instanceof Integer){
            int n = ((Integer) value).intValue();
            super.setValue(BinaryEditorUtil.toHexString(n));
        }
        else {
            super.setValue(value.toString());
        }
    }
}
