/*
 * Copyright (c) 2006 Suguru ARAKAWA. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.ac.hosei.k.cis.java2005.dita.swing;

import java.awt.Color;

import javax.swing.JTable;
import javax.swing.table.TableCellEditor;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableColumn;
import javax.swing.table.TableColumnModel;

/**
 * バイナリエディタの表示部。
 * @author arakawa
 * @version $Id: BinaryEditorPane.java,v 1.1 2005/11/17 05:14:12 java2005 Exp $
 */
public class BinaryEditorPane extends JTable {
    
    private static final long serialVersionUID = 1L;
    private final BinaryEditorTableModel editor;

    /**
     * インスタンスを生成する。
     */
    public BinaryEditorPane() {
        super(new BinaryEditorTableModel());
        this.editor = (BinaryEditorTableModel) this.dataModel;
        TableColumnModel cm = getColumnModel();
        
        // アドレス部の列
        cm.getColumn(0).setCellRenderer(new AddressCellRenderer());
        cm.getColumn(0).setMinWidth(80);
        cm.getColumn(0).setResizable(false);
        
        // データ部の列
        TableCellEditor binEditor = new BinaryEditorCellEditor();
        TableCellRenderer binRenderer = new BinaryEditorCellRenderer();
        int cols = getColumnCount();
        for (int i = 1; i < cols; i++) {
            TableColumn col = cm.getColumn(i);
            col.setCellEditor(binEditor);
            col.setCellRenderer(binRenderer);
            col.setPreferredWidth(40);
        }
        
        // ヘッダのDnDの禁止
        this.getTableHeader().setReorderingAllowed(false);
        
        // 選択色なし
        this.setSelectionBackground(new Color(0xe8ffe8));
    }
    
    /**
     * 指定した値にデータを設定しなおす。
     * @param data 設定するデータ
     * @throws NullPointerException 引数に<code>null</code>が含まれていた場合
     */
    public void setData(byte[] data) {
        if (data == null) {
            throw new NullPointerException("data"); //$NON-NLS-1$
        }
        this.editor.setData(data);
    }
    
    /**
     * 編集中のデータを取得する。
     * @return 取得したデータ
     */
    public byte[] getData() {
        return this.editor.getData();
    }
}
